# frozen_string_literal: true

require_relative "utils"

module Core
  module Define
    # [public]
    #
    class Definition
      def initialize(*namespace, name, location: nil)
        @name = name.to_sym
        @namespace = namespace.map(&:to_sym).freeze
        @location = location.freeze
        @constant = build_constant.freeze
      end

      # [public]
      #
      attr_reader :name

      # [public]
      #
      attr_reader :namespace

      # [public]
      #
      attr_reader :location

      # [public]
      #
      attr_reader :constant

      private def build_constant
        (@namespace + [@name]).map { |part|
          Utils.camelize(part)
        }.join("::")
      end
    end
  end
end
